@@ -49,7 +49,7 @@ class Dns:
     def add_service(self, name, protocol, type, port, url=None):
         self.port_mapper.add(port)
         new_service = Service(name, protocol, type, port, url)
-        self.service_config.add(new_service)
+        self.service_config.add_or_update(new_service)
 
     def get_service(self, name):
         return self.service_config.get(name)
