@@ -1,3 +1,4 @@
+import logging
 import unittest
 from mock import MagicMock
 
@@ -7,6 +8,7 @@ from insider.config import Port
 
 from helpers import get_port_config
 
+logging.basicConfig(level=logging.DEBUG)
 
 class TestFindAvailablePort(unittest.TestCase):
 
